==> commons-io-2.20.0-src.tar.gz: commons-io-2.20.0-src/src/test/java/org/apache/commons/io/test/ThrowOnCloseInputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.io.test;

import java.io.IOException;
import java.io.InputStream;

import org.apache.commons.io.input.NullInputStream;
import org.apache.commons.io.input.ProxyInputStream;

/**
 * Helper class for checking behavior of IO classes.
 */
public class ThrowOnCloseInputStream extends ProxyInputStream {

    /**
     * Constructs a new instance.
     */
    public ThrowOnCloseInputStream() {
        super(new NullInputStream());
    }

    /**
     * Constructs a new instance.
     *
     * @param proxy InputStream to delegate to.
     */
    public ThrowOnCloseInputStream(final InputStream proxy) {
        super(proxy);
    }

    /**
     * Always throws IOException.
     *
     * @see java.io.InputStream#close()
     */
    @Override
    public void close() throws IOException {
        throw new IOException(getClass().getSimpleName() + ".close() called.");
    }

}

==> commons-io-2.21.0-src.tar.gz: commons-io-2.21.0-src/src/test/java/org/apache/commons/io/test/ThrowOnCloseInputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.io.test;

import java.io.IOException;
import java.io.InputStream;

import org.apache.commons.io.input.NullInputStream;
import org.apache.commons.io.input.ProxyInputStream;

/**
 * Helper class for checking behavior of IO classes.
 */
public class ThrowOnCloseInputStream extends ProxyInputStream {

    /**
     * Constructs a new instance.
     */
    public ThrowOnCloseInputStream() {
        super(new NullInputStream());
    }

    /**
     * Constructs a new instance.
     *
     * @param proxy InputStream to delegate to.
     */
    public ThrowOnCloseInputStream(final InputStream proxy) {
        super(proxy);
    }

    /**
     * Always throws IOException.
     *
     * @see InputStream#close()
     */
    @Override
    public void close() throws IOException {
        throw new IOException(getClass().getSimpleName() + ".close() called.");
    }

}
